@@ -46,10 +46,10 @@ class FirefoxProfile(object):
         "browser.tabs.warnOnClose": "false",
         "browser.tabs.warnOnOpen": "false",
         "browser.startup.page": "0",
+        "browser.safebrowsing.malware.enabled": "false",
         "startup.homepage_welcome_url": "\"about:blank\"",
         "devtools.errorconsole.enabled": "true",
         "dom.disable_open_during_load": "false",
-        "dom.max_script_run_time": "30",
         "extensions.logging.enabled": "true",
         "extensions.update.enabled": "false",
         "extensions.update.notifyUser": "false",
@@ -75,7 +75,7 @@ class FirefoxProfile(object):
         "browser.dom.window.dump.enabled": "true",
         "webdriver_accept_untrusted_certs": "true",
         "webdriver_enable_native_events": "true",
-        "dom.max_script_run_time": "30"
+        "dom.max_script_run_time": "30",
         }
 
     def __init__(self,profile_directory=None):
@@ -90,10 +90,7 @@ class FirefoxProfile(object):
         if self.profile_dir is None:
             self.profile_dir = self._create_tempfolder()
         else:
-            newprof = os.path.join(
-                tempfile.gettempdir(), "webdriver-py-profilecopy")
-            if os.path.exists(newprof):
-                shutil.rmtree(newprof)
+            newprof = os.path.join(tempfile.mkdtemp(), "webdriver-py-profilecopy")
             shutil.copytree(self.profile_dir, newprof)
             self.profile_dir = newprof
             self._read_existing_userjs()
